summaryrefslogtreecommitdiffstats
path: root/ppapi
diff options
context:
space:
mode:
authorraymes@chromium.org <raymes@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-26 05:03:34 +0000
committerraymes@chromium.org <raymes@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-26 05:03:34 +0000
commitf5d324a0d8d889d7cc70b9a6d0385d68daaf5bf5 (patch)
tree5cebd00eff4a6a63a7a790b5d029b89a970acbac /ppapi
parente62b65a1dd07c8fd4e1fa61c67c65aecb75a316c (diff)
downloadchromium_src-f5d324a0d8d889d7cc70b9a6d0385d68daaf5bf5.zip
chromium_src-f5d324a0d8d889d7cc70b9a6d0385d68daaf5bf5.tar.gz
chromium_src-f5d324a0d8d889d7cc70b9a6d0385d68daaf5bf5.tar.bz2
Rename PPB_Find_Dev to PPB_Find_Private
This makes PPB_Find_Dev a private API and renames it as such. There is no intention to make this a public API. BUG=303491 Review URL: https://codereview.chromium.org/197623005 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@259497 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ppapi')
-rw-r--r--ppapi/api/private/ppb_find_private.idl (renamed from ppapi/api/dev/ppb_find_dev.idl)11
-rw-r--r--ppapi/api/private/ppp_find_private.idl (renamed from ppapi/api/dev/ppp_find_dev.idl)7
-rw-r--r--ppapi/c/private/ppb_find_private.h (renamed from ppapi/c/dev/ppb_find_dev.h)25
-rw-r--r--ppapi/c/private/ppp_find_private.h (renamed from ppapi/c/dev/ppp_find_dev.h)21
-rw-r--r--ppapi/cpp/dev/printing_dev.h2
-rw-r--r--ppapi/cpp/private/find_private.cc (renamed from ppapi/cpp/dev/find_dev.cc)44
-rw-r--r--ppapi/cpp/private/find_private.h (renamed from ppapi/cpp/dev/find_dev.h)24
-rw-r--r--ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c16
-rw-r--r--ppapi/ppapi_shared.gypi2
-rw-r--r--ppapi/ppapi_sources.gypi8
-rw-r--r--ppapi/proxy/interface_list.cc6
-rw-r--r--ppapi/proxy/ppp_find_proxy.cc16
-rw-r--r--ppapi/proxy/ppp_find_proxy.h6
-rw-r--r--ppapi/shared_impl/api_id.h2
-rw-r--r--ppapi/tests/all_c_includes.h4
-rw-r--r--ppapi/tests/all_cpp_includes.h2
-rw-r--r--ppapi/thunk/interfaces_ppb_public_dev.h1
-rw-r--r--ppapi/thunk/ppb_find_private_thunk.cc (renamed from ppapi/thunk/ppb_find_dev_thunk.cc)19
18 files changed, 107 insertions, 109 deletions
diff --git a/ppapi/api/dev/ppb_find_dev.idl b/ppapi/api/private/ppb_find_private.idl
index d43e62bb..6ab272d 100644
--- a/ppapi/api/dev/ppb_find_dev.idl
+++ b/ppapi/api/private/ppb_find_private.idl
@@ -1,10 +1,10 @@
-/* Copyright (c) 2012 The Chromium Authors. All rights reserved.
+/* Copyright 2014 The Chromium Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
/**
- * This file defines the <code>PPB_Find_Dev</code> interface.
+ * This file defines the <code>PPB_Find_Private</code> interface.
*/
[generate_thunk]
@@ -13,9 +13,10 @@ label Chrome {
M14 = 0.3
};
-// TODO(raymes): Make PPP/PPB_Find_Dev a private interface. It's only used by
-// PDF currently and it's restrictive in the way it can be used.
-interface PPB_Find_Dev {
+/**
+ * This is a private interface for doing browser Find in the PDF plugin.
+ */
+interface PPB_Find_Private {
/**
* Sets the instance of this plugin as the mechanism that will be used to
* handle find requests in the renderer. This will only succeed if the plugin
diff --git a/ppapi/api/dev/ppp_find_dev.idl b/ppapi/api/private/ppp_find_private.idl
index d277d95..bb6580c 100644
--- a/ppapi/api/dev/ppp_find_dev.idl
+++ b/ppapi/api/private/ppp_find_private.idl
@@ -1,4 +1,4 @@
-/* Copyright (c) 2014 The Chromium Authors. All rights reserved.
+/* Copyright 2014 The Chromium Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
@@ -7,10 +7,7 @@ label Chrome {
M14 = 0.3
};
-/**
- * TODO(raymes): Make PPP/PPB_Find_Dev a private interface.
- */
-interface PPP_Find_Dev {
+interface PPP_Find_Private {
/**
* Finds the given UTF-8 text starting at the current selection. The number of
* results will be updated asynchronously via NumberOfFindResultsChanged in
diff --git a/ppapi/c/dev/ppp_find_dev.h b/ppapi/c/private/ppp_find_private.h
index 6d9a4cc..00b26de 100644
--- a/ppapi/c/dev/ppp_find_dev.h
+++ b/ppapi/c/private/ppp_find_private.h
@@ -1,20 +1,20 @@
-/* Copyright (c) 2014 The Chromium Authors. All rights reserved.
+/* Copyright 2014 The Chromium Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
-/* From dev/ppp_find_dev.idl modified Wed Mar 19 14:02:22 2014. */
+/* From private/ppp_find_private.idl modified Thu Mar 20 11:34:17 2014. */
-#ifndef PPAPI_C_DEV_PPP_FIND_DEV_H_
-#define PPAPI_C_DEV_PPP_FIND_DEV_H_
+#ifndef PPAPI_C_PRIVATE_PPP_FIND_PRIVATE_H_
+#define PPAPI_C_PRIVATE_PPP_FIND_PRIVATE_H_
#include "ppapi/c/pp_bool.h"
#include "ppapi/c/pp_instance.h"
#include "ppapi/c/pp_macros.h"
#include "ppapi/c/pp_stdint.h"
-#define PPP_FIND_DEV_INTERFACE_0_3 "PPP_Find(Dev);0.3"
-#define PPP_FIND_DEV_INTERFACE PPP_FIND_DEV_INTERFACE_0_3
+#define PPP_FIND_PRIVATE_INTERFACE_0_3 "PPP_Find_Private;0.3"
+#define PPP_FIND_PRIVATE_INTERFACE PPP_FIND_PRIVATE_INTERFACE_0_3
/**
* @file
@@ -25,10 +25,7 @@
* @addtogroup Interfaces
* @{
*/
-/**
- * TODO(raymes): Make PPP/PPB_Find_Dev a private interface.
- */
-struct PPP_Find_Dev_0_3 {
+struct PPP_Find_Private_0_3 {
/**
* Finds the given UTF-8 text starting at the current selection. The number of
* results will be updated asynchronously via NumberOfFindResultsChanged in
@@ -52,10 +49,10 @@ struct PPP_Find_Dev_0_3 {
void (*StopFind)(PP_Instance instance);
};
-typedef struct PPP_Find_Dev_0_3 PPP_Find_Dev;
+typedef struct PPP_Find_Private_0_3 PPP_Find_Private;
/**
* @}
*/
-#endif /* PPAPI_C_DEV_PPP_FIND_DEV_H_ */
+#endif /* PPAPI_C_PRIVATE_PPP_FIND_PRIVATE_H_ */
diff --git a/ppapi/cpp/dev/printing_dev.h b/ppapi/cpp/dev/printing_dev.h
index b219b13..869dbac 100644
--- a/ppapi/cpp/dev/printing_dev.h
+++ b/ppapi/cpp/dev/printing_dev.h
@@ -15,7 +15,7 @@ namespace pp {
class Instance;
// You would typically use this either via inheritance on your instance or
-// by composition: see find_dev.h for an example.
+// by composition: see find_private.h for an example.
class Printing_Dev : public Resource {
public:
// The instance parameter must outlive this class.
diff --git a/ppapi/cpp/dev/find_dev.cc b/ppapi/cpp/private/find_private.cc
index 1004b49..bd592a4 100644
--- a/ppapi/cpp/dev/find_dev.cc
+++ b/ppapi/cpp/private/find_private.cc
@@ -1,10 +1,10 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "ppapi/cpp/dev/find_dev.h"
+#include "ppapi/cpp/private/find_private.h"
-#include "ppapi/c/dev/ppb_find_dev.h"
+#include "ppapi/c/private/ppb_find_private.h"
#include "ppapi/cpp/instance.h"
#include "ppapi/cpp/module.h"
#include "ppapi/cpp/module_impl.h"
@@ -13,11 +13,11 @@ namespace pp {
namespace {
-template <> const char* interface_name<PPB_Find_Dev>() {
- return PPB_FIND_DEV_INTERFACE;
+template <> const char* interface_name<PPB_Find_Private>() {
+ return PPB_FIND_PRIVATE_INTERFACE;
}
-static const char kPPPFindInterface[] = PPP_FIND_DEV_INTERFACE;
+static const char kPPPFindInterface[] = PPP_FIND_PRIVATE_INTERFACE;
PP_Bool StartFind(PP_Instance instance,
const char* text,
@@ -25,7 +25,7 @@ PP_Bool StartFind(PP_Instance instance,
void* object = Instance::GetPerInstanceObject(instance, kPPPFindInterface);
if (!object)
return PP_FALSE;
- bool return_value = static_cast<Find_Dev*>(object)->StartFind(
+ bool return_value = static_cast<Find_Private*>(object)->StartFind(
text, PP_ToBool(case_sensitive));
return PP_FromBool(return_value);
}
@@ -33,16 +33,16 @@ PP_Bool StartFind(PP_Instance instance,
void SelectFindResult(PP_Instance instance, PP_Bool forward) {
void* object = Instance::GetPerInstanceObject(instance, kPPPFindInterface);
if (object)
- static_cast<Find_Dev*>(object)->SelectFindResult(PP_ToBool(forward));
+ static_cast<Find_Private*>(object)->SelectFindResult(PP_ToBool(forward));
}
void StopFind(PP_Instance instance) {
void* object = Instance::GetPerInstanceObject(instance, kPPPFindInterface);
if (object)
- static_cast<Find_Dev*>(object)->StopFind();
+ static_cast<Find_Private*>(object)->StopFind();
}
-const PPP_Find_Dev ppp_find = {
+const PPP_Find_Private ppp_find = {
&StartFind,
&SelectFindResult,
&StopFind
@@ -50,33 +50,35 @@ const PPP_Find_Dev ppp_find = {
} // namespace
-Find_Dev::Find_Dev(Instance* instance) : associated_instance_(instance) {
+Find_Private::Find_Private(Instance* instance)
+ : associated_instance_(instance) {
Module::Get()->AddPluginInterface(kPPPFindInterface, &ppp_find);
instance->AddPerInstanceObject(kPPPFindInterface, this);
}
-Find_Dev::~Find_Dev() {
+Find_Private::~Find_Private() {
Instance::RemovePerInstanceObject(associated_instance_,
kPPPFindInterface, this);
}
-void Find_Dev::SetPluginToHandleFindRequests() {
- if (has_interface<PPB_Find_Dev>()) {
- get_interface<PPB_Find_Dev>()->SetPluginToHandleFindRequests(
+void Find_Private::SetPluginToHandleFindRequests() {
+ if (has_interface<PPB_Find_Private>()) {
+ get_interface<PPB_Find_Private>()->SetPluginToHandleFindRequests(
associated_instance_.pp_instance());
}
}
-void Find_Dev::NumberOfFindResultsChanged(int32_t total, bool final_result) {
- if (has_interface<PPB_Find_Dev>()) {
- get_interface<PPB_Find_Dev>()->NumberOfFindResultsChanged(
+void Find_Private::NumberOfFindResultsChanged(int32_t total,
+ bool final_result) {
+ if (has_interface<PPB_Find_Private>()) {
+ get_interface<PPB_Find_Private>()->NumberOfFindResultsChanged(
associated_instance_.pp_instance(), total, PP_FromBool(final_result));
}
}
-void Find_Dev::SelectedFindResultChanged(int32_t index) {
- if (has_interface<PPB_Find_Dev>()) {
- get_interface<PPB_Find_Dev>()->SelectedFindResultChanged(
+void Find_Private::SelectedFindResultChanged(int32_t index) {
+ if (has_interface<PPB_Find_Private>()) {
+ get_interface<PPB_Find_Private>()->SelectedFindResultChanged(
associated_instance_.pp_instance(), index);
}
}
diff --git a/ppapi/cpp/dev/find_dev.h b/ppapi/cpp/private/find_private.h
index a3170eb..80ecb98 100644
--- a/ppapi/cpp/dev/find_dev.h
+++ b/ppapi/cpp/private/find_private.h
@@ -1,13 +1,13 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef PPAPI_CPP_DEV_FIND_DEV_H_
-#define PPAPI_CPP_DEV_FIND_DEV_H_
+#ifndef PPAPI_CPP_PRIVATE_FIND_PRIVATE_H_
+#define PPAPI_CPP_PRIVATE_FIND_PRIVATE_H_
#include <string>
-#include "ppapi/c/dev/ppp_find_dev.h"
+#include "ppapi/c/private/ppp_find_private.h"
#include "ppapi/cpp/instance_handle.h"
namespace pp {
@@ -20,8 +20,8 @@ class Instance;
// browser calls.
//
// You would typically use this either via inheritance on your instance:
-// class MyInstance : public pp::Instance, public pp::Find_Dev {
-// class MyInstance() : pp::Find_Dev(this) {
+// class MyInstance : public pp::Instance, public pp::Find_Private {
+// class MyInstance() : pp::Find_Private(this) {
// }
// ...
// };
@@ -37,19 +37,19 @@ class Instance;
//
// MyFinder finder_;
// };
-class Find_Dev {
+class Find_Private {
public:
// The instance parameter must outlive this class.
- Find_Dev(Instance* instance);
- virtual ~Find_Dev();
+ Find_Private(Instance* instance);
+ virtual ~Find_Private();
- // PPP_Find_Dev functions exposed as virtual functions for you to
+ // PPP_Find_Private functions exposed as virtual functions for you to
// override.
virtual bool StartFind(const std::string& text, bool case_sensitive) = 0;
virtual void SelectFindResult(bool forward) = 0;
virtual void StopFind() = 0;
- // PPB_Find_Dev functions for you to call to report find results.
+ // PPB_Find_Private functions for you to call to report find results.
void SetPluginToHandleFindRequests();
void NumberOfFindResultsChanged(int32_t total, bool final_result);
void SelectedFindResultChanged(int32_t index);
@@ -60,4 +60,4 @@ class Find_Dev {
} // namespace pp
-#endif // PPAPI_CPP_DEV_FIND_DEV_H_
+#endif // PPAPI_CPP_PRIVATE_FIND_PRIVATE_H_
diff --git a/ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c b/ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c
index c64f180..70abd7d 100644
--- a/ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c
+++ b/ppapi/native_client/src/untrusted/pnacl_irt_shim/pnacl_shim.c
@@ -2020,8 +2020,6 @@ static int32_t Pnacl_M19_PPB_FileChooser_Dev_Show(PP_Resource chooser, struct PP
/* End wrapper methods for PPB_FileChooser_Dev_0_6 */
-/* Not generating wrapper methods for PPB_Find_Dev_0_3 */
-
/* Begin wrapper methods for PPB_Font_Dev_0_6 */
static void Pnacl_M14_PPB_Font_Dev_GetFontFamilies(struct PP_Var* _struct_result, PP_Instance instance) {
@@ -2402,8 +2400,6 @@ static void Pnacl_M14_PPB_VideoDecoder_Dev_Destroy(PP_Resource video_decoder) {
/* Not generating wrapper methods for PPB_Zoom_Dev_0_2 */
-/* Not generating wrapper methods for PPP_Find_Dev_0_3 */
-
/* Not generating wrapper methods for PPP_NetworkState_Dev_0_1 */
/* Not generating wrapper methods for PPP_Printing_Dev_0_6 */
@@ -2545,6 +2541,8 @@ static void Pnacl_M15_PPB_FileRefPrivate_GetAbsolutePath(struct PP_Var* _struct_
/* End wrapper methods for PPB_FileRefPrivate_0_1 */
+/* Not generating wrapper methods for PPB_Find_Private_0_3 */
+
/* Begin wrapper methods for PPB_Flash_12_4 */
static void Pnacl_M21_PPB_Flash_SetInstanceAlwaysOnTop(PP_Instance instance, PP_Bool on_top) {
@@ -4031,6 +4029,8 @@ static void Pnacl_M34_PPP_ContentDecryptor_Private_DecryptAndDecode(PP_Instance
/* End wrapper methods for PPP_ContentDecryptor_Private_0_11 */
+/* Not generating wrapper methods for PPP_Find_Private_0_3 */
+
/* Not generating wrapper methods for PPP_Flash_BrowserOperations_1_0 */
/* Not generating wrapper methods for PPP_Flash_BrowserOperations_1_2 */
@@ -4753,8 +4753,6 @@ static const struct PPB_FileChooser_Dev_0_6 Pnacl_Wrappers_PPB_FileChooser_Dev_0
.Show = (int32_t (*)(PP_Resource chooser, struct PP_ArrayOutput output, struct PP_CompletionCallback callback))&Pnacl_M19_PPB_FileChooser_Dev_Show
};
-/* Not generating wrapper interface for PPB_Find_Dev_0_3 */
-
static const struct PPB_Font_Dev_0_6 Pnacl_Wrappers_PPB_Font_Dev_0_6 = {
.GetFontFamilies = (struct PP_Var (*)(PP_Instance instance))&Pnacl_M14_PPB_Font_Dev_GetFontFamilies,
.Create = (PP_Resource (*)(PP_Instance instance, const struct PP_FontDescription_Dev* description))&Pnacl_M14_PPB_Font_Dev_Create,
@@ -4870,8 +4868,6 @@ static const struct PPB_VideoDecoder_Dev_0_16 Pnacl_Wrappers_PPB_VideoDecoder_De
/* Not generating wrapper interface for PPB_Zoom_Dev_0_2 */
-/* Not generating wrapper interface for PPP_Find_Dev_0_3 */
-
/* Not generating wrapper interface for PPP_NetworkState_Dev_0_1 */
/* Not generating wrapper interface for PPP_Printing_Dev_0_6 */
@@ -4927,6 +4923,8 @@ static const struct PPB_FileRefPrivate_0_1 Pnacl_Wrappers_PPB_FileRefPrivate_0_1
.GetAbsolutePath = (struct PP_Var (*)(PP_Resource file_ref))&Pnacl_M15_PPB_FileRefPrivate_GetAbsolutePath
};
+/* Not generating wrapper interface for PPB_Find_Private_0_3 */
+
static const struct PPB_Flash_12_4 Pnacl_Wrappers_PPB_Flash_12_4 = {
.SetInstanceAlwaysOnTop = (void (*)(PP_Instance instance, PP_Bool on_top))&Pnacl_M21_PPB_Flash_SetInstanceAlwaysOnTop,
.DrawGlyphs = (PP_Bool (*)(PP_Instance instance, PP_Resource pp_image_data, const struct PP_BrowserFont_Trusted_Description* font_desc, uint32_t color, const struct PP_Point* position, const struct PP_Rect* clip, const float transformation[3][3], PP_Bool allow_subpixel_aa, uint32_t glyph_count, const uint16_t glyph_indices[], const struct PP_Point glyph_advances[]))&Pnacl_M21_PPB_Flash_DrawGlyphs,
@@ -5307,6 +5305,8 @@ static const struct PPP_ContentDecryptor_Private_0_11 Pnacl_Wrappers_PPP_Content
.DecryptAndDecode = &Pnacl_M34_PPP_ContentDecryptor_Private_DecryptAndDecode
};
+/* Not generating wrapper interface for PPP_Find_Private_0_3 */
+
/* Not generating wrapper interface for PPP_Flash_BrowserOperations_1_0 */
/* Not generating wrapper interface for PPP_Flash_BrowserOperations_1_2 */
diff --git a/ppapi/ppapi_shared.gypi b/ppapi/ppapi_shared.gypi
index 620a6eb..8cd4064 100644
--- a/ppapi/ppapi_shared.gypi
+++ b/ppapi/ppapi_shared.gypi
@@ -170,7 +170,7 @@
'thunk/ppb_file_ref_thunk.cc',
'thunk/ppb_file_system_api.h',
'thunk/ppb_file_system_thunk.cc',
- 'thunk/ppb_find_dev_thunk.cc',
+ 'thunk/ppb_find_private_thunk.cc',
'thunk/ppb_flash_clipboard_api.h',
'thunk/ppb_flash_clipboard_thunk.cc',
'thunk/ppb_flash_device_id_thunk.cc',
diff --git a/ppapi/ppapi_sources.gypi b/ppapi/ppapi_sources.gypi
index cfb16fc..600f36b 100644
--- a/ppapi/ppapi_sources.gypi
+++ b/ppapi/ppapi_sources.gypi
@@ -82,7 +82,6 @@
'c/dev/ppb_cursor_control_dev.h',
'c/dev/ppb_device_ref_dev.h',
'c/dev/ppb_file_chooser_dev.h',
- 'c/dev/ppb_find_dev.h',
'c/dev/ppb_font_dev.h',
'c/dev/ppb_ime_input_event_dev.h',
'c/dev/ppb_memory_dev.h',
@@ -94,7 +93,6 @@
'c/dev/ppb_video_decoder_dev.h',
'c/dev/ppb_widget_dev.h',
'c/dev/ppb_zoom_dev.h',
- 'c/dev/ppp_find_dev.h',
'c/dev/ppp_network_state_dev.h',
'c/dev/ppp_scrollbar_dev.h',
'c/dev/ppp_selection_dev.h',
@@ -109,6 +107,7 @@
'c/private/pp_video_frame_private.h',
'c/private/ppb_content_decryptor_private.h',
'c/private/ppb_ext_crx_file_system_private.h',
+ 'c/private/ppb_find_private.h',
'c/private/ppb_flash.h',
'c/private/ppb_flash_clipboard.h',
'c/private/ppb_flash_file.h',
@@ -134,6 +133,7 @@
'c/private/ppb_video_source_private.h',
'c/private/ppb_x509_certificate_private.h',
'c/private/ppp_content_decryptor_private.h',
+ 'c/private/ppp_find_private.h',
'c/private/ppp_instance_private.h',
# Deprecated interfaces.
@@ -262,8 +262,6 @@
'cpp/dev/device_ref_dev.h',
'cpp/dev/file_chooser_dev.cc',
'cpp/dev/file_chooser_dev.h',
- 'cpp/dev/find_dev.cc',
- 'cpp/dev/find_dev.h',
'cpp/dev/font_dev.cc',
'cpp/dev/font_dev.h',
'cpp/dev/graphics_2d_dev.cc',
@@ -318,6 +316,8 @@
'cpp/private/ext_crx_file_system_private.h',
'cpp/private/file_io_private.cc',
'cpp/private/file_io_private.h',
+ 'cpp/private/find_private.cc',
+ 'cpp/private/find_private.h',
'cpp/private/flash.cc',
'cpp/private/flash.h',
'cpp/private/flash_clipboard.cc',
diff --git a/ppapi/proxy/interface_list.cc b/ppapi/proxy/interface_list.cc
index 3a6d988..a5f58d3 100644
--- a/ppapi/proxy/interface_list.cc
+++ b/ppapi/proxy/interface_list.cc
@@ -14,7 +14,6 @@
#include "ppapi/c/dev/ppb_crypto_dev.h"
#include "ppapi/c/dev/ppb_cursor_control_dev.h"
#include "ppapi/c/dev/ppb_device_ref_dev.h"
-#include "ppapi/c/dev/ppb_find_dev.h"
#include "ppapi/c/dev/ppb_font_dev.h"
#include "ppapi/c/dev/ppb_gles_chromium_texture_mapping_dev.h"
#include "ppapi/c/dev/ppb_graphics_2d_dev.h"
@@ -76,6 +75,7 @@
#include "ppapi/c/private/ppb_ext_crx_file_system_private.h"
#include "ppapi/c/private/ppb_file_io_private.h"
#include "ppapi/c/private/ppb_file_ref_private.h"
+#include "ppapi/c/private/ppb_find_private.h"
#include "ppapi/c/private/ppb_flash_clipboard.h"
#include "ppapi/c/private/ppb_flash_file.h"
#include "ppapi/c/private/ppb_flash_font_file.h"
@@ -303,8 +303,8 @@ InterfaceList::InterfaceList() {
#if !defined(OS_NACL)
AddProxy(API_ID_PPP_PDF, &ProxyFactory<PPP_Pdf_Proxy>);
AddPPP(PPP_PDF_INTERFACE, PPP_Pdf_Proxy::GetProxyInterface());
- AddProxy(API_ID_PPP_FIND_DEV, &ProxyFactory<PPP_Find_Proxy>);
- AddPPP(PPP_FIND_DEV_INTERFACE, PPP_Find_Proxy::GetProxyInterface());
+ AddProxy(API_ID_PPP_FIND_PRIVATE, &ProxyFactory<PPP_Find_Proxy>);
+ AddPPP(PPP_FIND_PRIVATE_INTERFACE, PPP_Find_Proxy::GetProxyInterface());
AddProxy(API_ID_PPP_VIDEO_DECODER_DEV, &ProxyFactory<PPP_VideoDecoder_Proxy>);
AddPPP(PPP_VIDEODECODER_DEV_INTERFACE,
PPP_VideoDecoder_Proxy::GetProxyInterface());
diff --git a/ppapi/proxy/ppp_find_proxy.cc b/ppapi/proxy/ppp_find_proxy.cc
index 0547e61..abd5663 100644
--- a/ppapi/proxy/ppp_find_proxy.cc
+++ b/ppapi/proxy/ppp_find_proxy.cc
@@ -20,7 +20,7 @@ PP_Bool StartFind(PP_Instance instance,
PP_Bool case_sensitive) {
DCHECK(case_sensitive == PP_FALSE);
HostDispatcher::GetForInstance(instance)->Send(
- new PpapiPluginMsg_PPPFind_StartFind(API_ID_PPP_FIND_DEV,
+ new PpapiPluginMsg_PPPFind_StartFind(API_ID_PPP_FIND_PRIVATE,
instance,
text));
return PP_TRUE;
@@ -29,23 +29,23 @@ PP_Bool StartFind(PP_Instance instance,
void SelectFindResult(PP_Instance instance,
PP_Bool forward) {
HostDispatcher::GetForInstance(instance)->Send(
- new PpapiPluginMsg_PPPFind_SelectFindResult(API_ID_PPP_FIND_DEV,
+ new PpapiPluginMsg_PPPFind_SelectFindResult(API_ID_PPP_FIND_PRIVATE,
instance, forward));
}
void StopFind(PP_Instance instance) {
HostDispatcher::GetForInstance(instance)->Send(
- new PpapiPluginMsg_PPPFind_StopFind(API_ID_PPP_FIND_DEV, instance));
+ new PpapiPluginMsg_PPPFind_StopFind(API_ID_PPP_FIND_PRIVATE, instance));
}
-const PPP_Find_Dev ppp_find_interface = {
+const PPP_Find_Private ppp_find_interface = {
&StartFind,
&SelectFindResult,
&StopFind
};
#else
// The NaCl plugin doesn't need the host side interface - stub it out.
-const PPP_Find_Dev ppp_find_interface = {};
+const PPP_Find_Private ppp_find_interface = {};
#endif
} // namespace
@@ -54,8 +54,8 @@ PPP_Find_Proxy::PPP_Find_Proxy(Dispatcher* dispatcher)
: InterfaceProxy(dispatcher),
ppp_find_(NULL) {
if (dispatcher->IsPlugin()) {
- ppp_find_ = static_cast<const PPP_Find_Dev*>(
- dispatcher->local_get_interface()(PPP_FIND_DEV_INTERFACE));
+ ppp_find_ = static_cast<const PPP_Find_Private*>(
+ dispatcher->local_get_interface()(PPP_FIND_PRIVATE_INTERFACE));
}
}
@@ -63,7 +63,7 @@ PPP_Find_Proxy::~PPP_Find_Proxy() {
}
// static
-const PPP_Find_Dev* PPP_Find_Proxy::GetProxyInterface() {
+const PPP_Find_Private* PPP_Find_Proxy::GetProxyInterface() {
return &ppp_find_interface;
}
diff --git a/ppapi/proxy/ppp_find_proxy.h b/ppapi/proxy/ppp_find_proxy.h
index fa0961e..6d22304 100644
--- a/ppapi/proxy/ppp_find_proxy.h
+++ b/ppapi/proxy/ppp_find_proxy.h
@@ -7,7 +7,7 @@
#include <string>
-#include "ppapi/c/dev/ppp_find_dev.h"
+#include "ppapi/c/private/ppp_find_private.h"
#include "ppapi/proxy/interface_proxy.h"
namespace ppapi {
@@ -19,7 +19,7 @@ class PPP_Find_Proxy : public InterfaceProxy {
explicit PPP_Find_Proxy(Dispatcher* dispatcher);
virtual ~PPP_Find_Proxy();
- static const PPP_Find_Dev* GetProxyInterface();
+ static const PPP_Find_Private* GetProxyInterface();
// InterfaceProxy implementation.
virtual bool OnMessageReceived(const IPC::Message& msg);
@@ -35,7 +35,7 @@ class PPP_Find_Proxy : public InterfaceProxy {
// When this proxy is in the plugin side, this value caches the interface
// pointer so we don't have to retrieve it from the dispatcher each time.
// In the host, this value is always NULL.
- const PPP_Find_Dev* ppp_find_;
+ const PPP_Find_Private* ppp_find_;
DISALLOW_COPY_AND_ASSIGN(PPP_Find_Proxy);
};
diff --git a/ppapi/shared_impl/api_id.h b/ppapi/shared_impl/api_id.h
index 2f18a85..a049948 100644
--- a/ppapi/shared_impl/api_id.h
+++ b/ppapi/shared_impl/api_id.h
@@ -50,7 +50,7 @@ enum ApiID {
// TODO(tomfinegan): Remove this after we refactor things to load the PPP
// interface struct from the PPB interface.
API_ID_PPP_CONTENT_DECRYPTOR_PRIVATE,
- API_ID_PPP_FIND_DEV,
+ API_ID_PPP_FIND_PRIVATE,
API_ID_PPP_GRAPHICS_3D,
API_ID_PPP_INPUT_EVENT,
API_ID_PPP_INSTANCE,
diff --git a/ppapi/tests/all_c_includes.h b/ppapi/tests/all_c_includes.h
index ddaa8a8..b74675c 100644
--- a/ppapi/tests/all_c_includes.h
+++ b/ppapi/tests/all_c_includes.h
@@ -19,7 +19,6 @@
#include "ppapi/c/dev/ppb_cursor_control_dev.h"
#include "ppapi/c/dev/ppb_device_ref_dev.h"
#include "ppapi/c/dev/ppb_file_chooser_dev.h"
-#include "ppapi/c/dev/ppb_find_dev.h"
#include "ppapi/c/dev/ppb_font_dev.h"
#include "ppapi/c/dev/ppb_graphics_2d_dev.h"
#include "ppapi/c/dev/ppb_ime_input_event_dev.h"
@@ -36,7 +35,6 @@
#include "ppapi/c/dev/ppb_widget_dev.h"
#include "ppapi/c/dev/ppb_zoom_dev.h"
#include "ppapi/c/dev/ppp_class_deprecated.h"
-#include "ppapi/c/dev/ppp_find_dev.h"
#include "ppapi/c/dev/ppp_printing_dev.h"
#include "ppapi/c/dev/ppp_scrollbar_dev.h"
#include "ppapi/c/dev/ppp_selection_dev.h"
@@ -112,6 +110,7 @@
#include "ppapi/c/private/ppb_display_color_profile_private.h"
#include "ppapi/c/private/ppb_ext_crx_file_system_private.h"
#include "ppapi/c/private/ppb_file_io_private.h"
+#include "ppapi/c/private/ppb_find_private.h"
#include "ppapi/c/private/ppb_flash.h"
#include "ppapi/c/private/ppb_flash_clipboard.h"
#include "ppapi/c/private/ppb_flash_font_file.h"
@@ -133,6 +132,7 @@
#include "ppapi/c/private/ppb_video_source_private.h"
#include "ppapi/c/private/ppb_x509_certificate_private.h"
#include "ppapi/c/private/ppp_content_decryptor_private.h"
+#include "ppapi/c/private/ppp_find_private.h"
#include "ppapi/c/private/ppp_instance_private.h"
#include "ppapi/c/trusted/ppb_url_loader_trusted.h"
diff --git a/ppapi/tests/all_cpp_includes.h b/ppapi/tests/all_cpp_includes.h
index aa66777..dcb907c 100644
--- a/ppapi/tests/all_cpp_includes.h
+++ b/ppapi/tests/all_cpp_includes.h
@@ -18,7 +18,6 @@
#include "ppapi/cpp/dev/buffer_dev.h"
#include "ppapi/cpp/dev/device_ref_dev.h"
#include "ppapi/cpp/dev/file_chooser_dev.h"
-#include "ppapi/cpp/dev/find_dev.h"
#include "ppapi/cpp/dev/font_dev.h"
#include "ppapi/cpp/dev/graphics_2d_dev.h"
#include "ppapi/cpp/dev/ime_input_event_dev.h"
@@ -61,6 +60,7 @@
#include "ppapi/cpp/network_proxy.h"
#include "ppapi/cpp/point.h"
#include "ppapi/cpp/private/content_decryptor_private.h"
+#include "ppapi/cpp/private/find_private.h"
#include "ppapi/cpp/private/flash_font_file.h"
#include "ppapi/cpp/private/flash_fullscreen.h"
#include "ppapi/cpp/private/instance_private.h"
diff --git a/ppapi/thunk/interfaces_ppb_public_dev.h b/ppapi/thunk/interfaces_ppb_public_dev.h
index cbff2d4a..39855b9 100644
--- a/ppapi/thunk/interfaces_ppb_public_dev.h
+++ b/ppapi/thunk/interfaces_ppb_public_dev.h
@@ -16,7 +16,6 @@ PROXIED_IFACE(PPB_EXT_SOCKET_DEV_INTERFACE_0_1, PPB_Ext_Socket_Dev_0_1)
PROXIED_IFACE(PPB_EXT_SOCKET_DEV_INTERFACE_0_2, PPB_Ext_Socket_Dev_0_2)
PROXIED_IFACE(PPB_FILECHOOSER_DEV_INTERFACE_0_5, PPB_FileChooser_Dev_0_5)
PROXIED_IFACE(PPB_FILECHOOSER_DEV_INTERFACE_0_6, PPB_FileChooser_Dev_0_6)
-PROXIED_IFACE(PPB_FIND_DEV_INTERFACE_0_3, PPB_Find_Dev_0_3)
PROXIED_IFACE(PPB_IME_INPUT_EVENT_DEV_INTERFACE_0_2, PPB_IMEInputEvent_Dev_0_2)
PROXIED_IFACE(PPB_MEMORY_DEV_INTERFACE_0_1, PPB_Memory_Dev_0_1)
PROXIED_IFACE(PPB_PRINTING_DEV_INTERFACE_0_7, PPB_Printing_Dev_0_7)
diff --git a/ppapi/thunk/ppb_find_dev_thunk.cc b/ppapi/thunk/ppb_find_private_thunk.cc
index 91224f9..f530b62 100644
--- a/ppapi/thunk/ppb_find_dev_thunk.cc
+++ b/ppapi/thunk/ppb_find_private_thunk.cc
@@ -1,11 +1,11 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// From dev/ppb_find_dev.idl modified Thu Mar 13 11:05:53 2014.
+// From private/ppb_find_private.idl modified Thu Mar 13 11:56:31 2014.
-#include "ppapi/c/dev/ppb_find_dev.h"
#include "ppapi/c/pp_errors.h"
+#include "ppapi/c/private/ppb_find_private.h"
#include "ppapi/shared_impl/tracked_callback.h"
#include "ppapi/thunk/enter.h"
#include "ppapi/thunk/ppapi_thunk_export.h"
@@ -16,7 +16,7 @@ namespace thunk {
namespace {
void SetPluginToHandleFindRequests(PP_Instance instance) {
- VLOG(4) << "PPB_Find_Dev::SetPluginToHandleFindRequests()";
+ VLOG(4) << "PPB_Find_Private::SetPluginToHandleFindRequests()";
EnterInstance enter(instance);
if (enter.failed())
return;
@@ -26,7 +26,7 @@ void SetPluginToHandleFindRequests(PP_Instance instance) {
void NumberOfFindResultsChanged(PP_Instance instance,
int32_t total,
PP_Bool final_result) {
- VLOG(4) << "PPB_Find_Dev::NumberOfFindResultsChanged()";
+ VLOG(4) << "PPB_Find_Private::NumberOfFindResultsChanged()";
EnterInstance enter(instance);
if (enter.failed())
return;
@@ -34,14 +34,14 @@ void NumberOfFindResultsChanged(PP_Instance instance,
}
void SelectedFindResultChanged(PP_Instance instance, int32_t index) {
- VLOG(4) << "PPB_Find_Dev::SelectedFindResultChanged()";
+ VLOG(4) << "PPB_Find_Private::SelectedFindResultChanged()";
EnterInstance enter(instance);
if (enter.failed())
return;
enter.functions()->SelectedFindResultChanged(instance, index);
}
-const PPB_Find_Dev_0_3 g_ppb_find_dev_thunk_0_3 = {
+const PPB_Find_Private_0_3 g_ppb_find_private_thunk_0_3 = {
&SetPluginToHandleFindRequests,
&NumberOfFindResultsChanged,
&SelectedFindResultChanged
@@ -49,8 +49,9 @@ const PPB_Find_Dev_0_3 g_ppb_find_dev_thunk_0_3 = {
} // namespace
-PPAPI_THUNK_EXPORT const PPB_Find_Dev_0_3* GetPPB_Find_Dev_0_3_Thunk() {
- return &g_ppb_find_dev_thunk_0_3;
+PPAPI_THUNK_EXPORT const PPB_Find_Private_0_3*
+ GetPPB_Find_Private_0_3_Thunk() {
+ return &g_ppb_find_private_thunk_0_3;
}
} // namespace thunk
diff --git a/ppapi/c/dev/ppb_find_dev.h b/ppapi/c/private/ppb_find_private.h
index 15b8f27..3aaaabd 100644
--- a/ppapi/c/dev/ppb_find_dev.h
+++ b/ppapi/c/private/ppb_find_private.h
@@ -1,24 +1,24 @@
-/* Copyright (c) 2012 The Chromium Authors. All rights reserved.
+/* Copyright 2014 The Chromium Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
-/* From dev/ppb_find_dev.idl modified Thu Mar 13 11:05:53 2014. */
+/* From private/ppb_find_private.idl modified Thu Mar 13 11:56:31 2014. */
-#ifndef PPAPI_C_DEV_PPB_FIND_DEV_H_
-#define PPAPI_C_DEV_PPB_FIND_DEV_H_
+#ifndef PPAPI_C_PRIVATE_PPB_FIND_PRIVATE_H_
+#define PPAPI_C_PRIVATE_PPB_FIND_PRIVATE_H_
#include "ppapi/c/pp_bool.h"
#include "ppapi/c/pp_instance.h"
#include "ppapi/c/pp_macros.h"
#include "ppapi/c/pp_stdint.h"
-#define PPB_FIND_DEV_INTERFACE_0_3 "PPB_Find(Dev);0.3"
-#define PPB_FIND_DEV_INTERFACE PPB_FIND_DEV_INTERFACE_0_3
+#define PPB_FIND_PRIVATE_INTERFACE_0_3 "PPB_Find_Private;0.3"
+#define PPB_FIND_PRIVATE_INTERFACE PPB_FIND_PRIVATE_INTERFACE_0_3
/**
* @file
* This file defines the <code>PPB_Find_Dev</code> interface.
*/
@@ -26,9 +26,10 @@
* @addtogroup Interfaces
* @{
*/
-/* TODO(raymes): Make PPP/PPB_Find_Dev a private interface. It's only used by
- * PDF currently and it's restrictive in the way it can be used. */
-struct PPB_Find_Dev_0_3 {
+/**
+ * This is a private interface for doing browser Find in the PDF plugin.
+ */
+struct PPB_Find_Private_0_3 {
/**
* Sets the instance of this plugin as the mechanism that will be used to
* handle find requests in the renderer. This will only succeed if the plugin
@@ -61,10 +62,10 @@ struct PPB_Find_Dev_0_3 {
void (*SelectedFindResultChanged)(PP_Instance instance, int32_t index);
};
-typedef struct PPB_Find_Dev_0_3 PPB_Find_Dev;
+typedef struct PPB_Find_Private_0_3 PPB_Find_Private;
/**
* @}
*/
-#endif /* PPAPI_C_DEV_PPB_FIND_DEV_H_ */
+#endif /* PPAPI_C_PRIVATE_PPB_FIND_PRIVATE_H_ */
@@ -1,24 +1,24 @@
/**
* @file
- * This file defines the <code>PPB_Find_Dev</code> interface.
+ * This file defines the <code>PPB_Find_Private</code> interface.
*/